@@ -1,4 +1,4 @@
-//@line 40 "/icecat-3.6.7/toolkit/content/customizeToolbar.js"
+//@line 40 "/icecat-3.6/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
 
@@ -192,7 +192,7 @@ function wrapToolbarItems()
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
 
-//@line 237 "/icecat-3.6.7/toolkit/content/customizeToolbar.js"
+//@line 237 "/icecat-3.6/toolkit/content/customizeToolbar.js"
 
         if (isToolbarItem(item)) {
           var wrapper = wrapToolbarItem(item);
@@ -421,7 +421,7 @@ function fillRowWithFlex(aRow)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of any attributes that may adversely affect its
+ * is stripped of all properties that may adversely affect its
  * appearance in the palette.
  */
 function cleanUpItemForPalette(aItem, aWrapper)
@@ -441,14 +441,13 @@ function cleanUpItemForPalette(aItem, aWrapper)
   // Remove attributes that screw up our appearance.
   aItem.removeAttribute("command");
   aItem.removeAttribute("observes");
+  aItem.removeAttribute("disabled");
   aItem.removeAttribute("type");
   aItem.removeAttribute("width");
 
-  Array.forEach(aWrapper.querySelectorAll("[disabled]"), function(aNode) {
-    aNode.removeAttribute("disabled");
-  });
-
   if (aItem.localName == "toolbaritem" && aItem.firstChild) {
+    aItem.firstChild.removeAttribute("observes");
+
     // So the throbber doesn't throb in the dialog,
     // cute as that may be...
     aItem.firstChild.removeAttribute("busy");
