@@ -1,4 +1,4 @@
-//@line 39 "/icecat-3.6.7/toolkit/content/nsDragAndDrop.js"
+//@line 39 "/icecat-3.6/toolkit/content/nsDragAndDrop.js"
 
 ////////////////////////////////////////////////////////////////////////
 //
@@ -548,6 +548,13 @@ var nsDragAndDrop = {
    **/
   dragDropSecurityCheck: function (aEvent, aDragSession, aDraggedText)
     {
+      if (!aDragSession)
+        aDragSession = this.mDragService.getCurrentSession();
+
+      var sourceDoc = aDragSession.sourceDocument;
+      if (!sourceDoc)
+        return;
+
       // Strip leading and trailing whitespace, then try to create a
       // URI from the dropped string. If that succeeds, we're
       // dropping a URI and we need to do a security check to make
@@ -576,16 +583,8 @@ var nsDragAndDrop = {
       var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
                              .getService(nsIScriptSecurityManager);
 
-      if (!aDragSession)
-        aDragSession = this.mDragService.getCurrentSession();
-
-      var sourceDoc = aDragSession.sourceDocument;
-      // Use "file:///" as the default sourceURI so that drops of file:// URIs
-      // are always allowed.
-      var sourceURI = sourceDoc ? sourceDoc.documentURI : "file:///";
-
       try {
-        secMan.checkLoadURIStr(sourceURI, aDraggedText,
+        secMan.checkLoadURIStr(sourceDoc.documentURI, aDraggedText,
                                nsIScriptSecurityManager.STANDARD);
       } catch (e) {
         // Stop event propagation right here.
